@@ -53,14 +53,21 @@ scaclust <- function (x, centers, iter.max = 100, verbose = FALSE,
   iter <- integer(1)
   
 ##  if ((method == 1) || (method == 2) || (method == 3)){
-    retval <- .C("common", xrows = as.integer(xrows),
+    retval <- .C("common",
+                 xrows = as.integer(xrows),
                  xcols = as.integer(xcols), 
-                 x = as.double(x), ncenters = as.integer(ncenters), 
+                 x = as.double(x),
+                 ncenters = as.integer(ncenters), 
                  centers = as.double(centers), 
-                 itermax = as.integer(iter.max), iter = as.integer(iter), 
-                 verbose = as.integer(verbose), U=double(xrows*ncenters),
-                 beta=as.double(beta), taf=as.double(taf),
-                 theta=as.double(theta),ermin=double(1))
+                 itermax = as.integer(iter.max),
+                 iter = as.integer(iter), 
+                 verbose = as.integer(verbose),
+                 U = double(xrows*ncenters),
+                 beta = as.double(beta),
+                 taf = as.double(taf),
+                 theta = as.double(theta),
+                 ermin = double(1),
+                 PACKAGE = "e1071")
 
   centers <- matrix(retval$centers, ncol = xcols, dimnames = dimnames(initcenters))
   
